import json


class PortalError(RuntimeError):
    """Base exception class
    """


class PortalAPIError(Exception):
    def __init__(self, code, message):
        self._code = code
        self._message = message

    @property
    def code(self):
        return self._code

    @property
    def message(self):
        return self._message

    @property
    def json(self):
        return json.dumps(self.message)

    def __str__(self):
        return self.__class__.__name__ + ': ' + self.message


class ResourceNotFoundError(PortalAPIError):
    def __init__(self, resource: str, res_id=None, note=None):
        message = dict(
            resource=resource,
            id=res_id,
            message=f"Cannot find {resource} with identifier: {res_id}",
        )
        if note:
            message['note'] = note

        super().__init__(code=404, message=message)


class UnauthorizedError(PortalAPIError):
    def __init__(self, note=None):
        message = dict(
            message=f"You are not autorized!",
        )
        if note:
            message['note'] = note

        super().__init__(code=401, message=message)


class ForbiddenError(PortalAPIError):
    def __init__(self, uid, note=None):
        message = dict(
            uid=uid,
            message=f"Forbidden for user: {uid}!",
        )
        if note:
            message['note'] = note

        super().__init__(code=401, message=message)
