import os
import pytest

from portal import create_app
from portal import db


@pytest.fixture(scope='session')
def app():
    os.environ["PORTAL_CONFIG_TYPE"] = 'test'
    _app = create_app()
    from tests import init_db
    init_db(_app)
    with _app.app_context():
        db.create_all()
        yield _app
        db.session.remove()
        db.drop_all()


@pytest.fixture(scope='function')
def session(app):
    """
    Creates a new database session (with a working transaction)
    for the duration of a test.
    """
    # initialize a new app context
    with app.app_context():
        _session = db.create_scoped_session()
        yield _session
        # the code after yield serves as session teardown
        _session.rollback()
        _session.close()


''' SOURCES
http://piotr.banaszkiewicz.org/blog/2014/02/22/how-to-bite-flask-sqlalchemy-and-pytest-all-at-once/
http://alexmic.net/flask-sqlalchemy-pytest/
https://xvrdm.github.io/2017/07/03/testing-flask-sqlalchemy-database-with-pytest/
https://scotch.io/tutorials/build-a-crud-web-app-with-python-and-flask-part-one
'''
